@@ -1,9 +1,9 @@
 #!/usr/bin/python3
 
-from lintian_brush.control import (
-    ControlUpdater,
+from debmutate.control import (
+    ControlEditor,
     )
-from lintian_brush.debhelper import (
+from debmutate.debhelper import (
     ensure_minimum_debhelper_version,
     )
 from lintian_brush.fixer import report_result
@@ -24,7 +24,7 @@ def cb(line, target):
 
 
 if update_rules(cb):
-    with ControlUpdater() as updater:
+    with ControlEditor() as updater:
         ensure_minimum_debhelper_version(updater.source, "9.20160114")
 
 
